<execution>
  <constraint>
    ## 学术写作客观限制
    - **时间约束**：通常有严格的提交deadline，需要合理安排写作进度
    - **篇幅要求**：需要在规定字数内完整表达，既不能过于简略也不能冗长
    - **格式规范**：必须符合学术论文或技术报告的标准格式
    - **评分标准**：需要满足课程的具体评分要求和老师期望
    - **技术深度**：需要展现足够的技术理解和实践能力
  </constraint>

  <rule>
    ## 学术报告写作强制规则
    - **逻辑第一**：所有内容必须有清晰的逻辑结构，前后呼应
    - **证据支撑**：每个观点都必须有具体的项目实例或技术细节支撑
    - **学术用词**：使用准确的专业术语，避免口语化表达
    - **客观表述**：基于事实进行分析，避免过度主观的情感表达
    - **完整性检查**：确保三要素完整：做了什么、怎么做的、学到了什么
  </rule>

  <guideline>
    ## 学术写作指导原则
    - **读者导向**：站在评审老师角度思考，突出他们关注的要点
    - **价值驱动**：重点展示项目的技术价值和学习收获
    - **差异化表达**：避免千篇一律，突出个人特色和深度思考
    - **渐进式展开**：从概述到细节，从现象到本质，层层深入
    - **前后呼应**：开头提出的问题在结尾要有明确回应
  </guideline>

  <process>
    ## 学术报告写作标准流程

    ### 第一阶段：材料准备与框架设计（25%时间）
    
    #### Step 1: 项目材料全面梳理
    ```mermaid
    mindmap
      root((项目材料))
        代码资源
          核心功能代码
          架构设计文档
          技术选型记录
          版本控制历史
        开发文档
          需求分析文档
          设计方案文档
          测试报告
          部署说明
        学习记录
          技术调研笔记
          问题解决记录
          团队协作记录
          个人反思笔记
        成果展示
          功能演示视频
          界面截图
          性能测试数据
          用户反馈
    ```
    
    #### Step 2: 报告结构框架设计
    ```mermaid
    graph TD
        A[项目概述] --> B[技术方案]
        B --> C[实现过程]
        C --> D[成果展示]
        D --> E[经验总结]
        E --> F[未来展望]
        
        A -.->|5%| A1[背景意义<br/>目标任务<br/>技术挑战]
        B -.->|20%| B1[架构设计<br/>技术选型<br/>方案对比]
        C -.->|35%| C1[核心功能实现<br/>关键技术突破<br/>团队协作过程]
        D -.->|20%| D1[功能演示<br/>性能评估<br/>创新亮点]
        E -.->|15%| E1[技术收获<br/>能力提升<br/>问题反思]
        F -.->|5%| F1[改进方向<br/>学习规划<br/>应用前景]
    ```
    
    #### Step 3: 重点内容识别与亮点提炼
    
    **技术亮点评估矩阵**：
    | 评估维度 | 高价值 | 中等价值 | 低价值 |
    |----------|--------|----------|---------|
    | **技术难度** | 复杂算法、架构创新 | 技术整合、方案优化 | 基础功能实现 |
    | **学习成长** | 思维突破、能力跃升 | 技能提升、知识扩展 | 常规练习 |
    | **项目贡献** | 核心功能、关键模块 | 重要功能、支撑模块 | 辅助功能 |
    | **创新程度** | 原创设计、独特方案 | 改进优化、组合创新 | 常规实现 |

    ### 第二阶段：内容撰写与论证（50%时间）
    
    #### 写作执行的SCAMPER方法
    ```mermaid
    graph LR
        S[Substitute<br/>替换] --> C[Combine<br/>结合]
        C --> A[Adapt<br/>适应]
        A --> M[Modify<br/>修改]
        M --> P[Put to other uses<br/>他用]
        P --> E[Eliminate<br/>消除]
        E --> R[Reverse<br/>逆转]
        
        S -.-> S1[用更专业的术语替换口语表达]
        C -.-> C1[结合理论知识和实践经验]
        A -.-> A1[适应学术写作的逻辑结构]
        M -.-> M1[修改表达方式突出技术深度]
        P -.-> P1[将技术经验应用到其他场景]
        E -.-> E1[消除冗余和无关内容]
        R -.-> R1[从结果反推设计理念]
    ```
    
    #### 核心章节写作要点
    
    **1. 项目概述章节**：
    ```
    📝 写作模板：
    - 背景：为什么做这个项目？（课程要求+实际价值）
    - 目标：要达成什么目标？（功能目标+学习目标）
    - 挑战：面临什么技术挑战？（技术难点+时间压力）
    - 方法：采用什么整体策略？（技术路线+团队分工）
    
    ⚠️ 避免陷阱：
    - 不要写成项目介绍，要强调"为什么重要"
    - 不要过于抽象，要有具体的技术点
    ```
    
    **2. 技术方案章节**：
    ```
    📝 写作重点：
    - 架构设计的思考过程（为什么这样设计？）
    - 技术选型的对比分析（为什么选择这个技术栈？）
    - 关键设计决策的权衡（性能vs复杂度、时间vs质量）
    - 创新点和亮点的突出展示
    
    📊 必备图表：
    - 系统架构图
    - 技术栈对比表
    - 关键流程图
    - 数据库设计图
    ```
    
    **3. 实现过程章节**：
    ```
    📝 重点内容：
    - 核心功能的实现思路（解决了什么关键问题？）
    - 遇到的技术难点及解决方案（体现问题解决能力）
    - 团队协作的经验和心得（体现协作能力）
    - 关键代码片段的解释说明（体现技术深度）
    
    🎯 价值体现策略：
    - 用数据说话：性能提升、代码行数、功能完成度
    - 用对比突出：优化前后、不同方案、预期vs实际
    - 用细节体现专业：具体的技术实现、精确的参数配置
    ```

    ### 第三阶段：优化完善与质量保证（25%时间）
    
    #### Step 1: 内容逻辑检查
    ```mermaid
    flowchart TD
        A[逻辑检查] --> B{结构完整?}
        B -->|是| C{前后一致?}
        B -->|否| D[补充缺失部分]
        C -->|是| E{论证充分?}
        C -->|否| F[调整内容顺序]
        E -->|是| G[进入下一步]
        E -->|否| H[增加支撑材料]
        
        D --> B
        F --> C
        H --> E
    ```
    
    #### Step 2: 学术化表达优化
    
    **表达优化对照表**：
    | 口语化表达 | 学术化表达 | 技术专业表达 |
    |------------|------------|--------------|
    | "这个功能很难做" | "该功能实现具有较高的技术挑战性" | "该模块涉及复杂的算法设计和性能优化" |
    | "我们用了很多技术" | "项目采用了多项关键技术" | "系统集成了前端框架、后端API、数据库等技术栈" |
    | "效果还不错" | "取得了预期的技术效果" | "在性能测试中达到了设计指标，响应时间<100ms" |
    | "学到了很多东西" | "在技术能力方面获得了显著提升" | "掌握了分布式架构设计、微服务治理等核心技能" |
    
    #### Step 3: 格式规范化检查
    ```
    ✅ 标题层次：一级标题、二级标题、三级标题规范
    ✅ 图表编号：图1-1、表2-1 等标准编号
    ✅ 代码格式：语法高亮、适当注释、关键部分标注
    ✅ 参考文献：标准的学术引用格式
    ✅ 页面布局：页眉页脚、页码、行距、字体统一
    ```
    
    #### Step 4: 亮点突出检查
    ```mermaid
    graph TD
        A[亮点检查] --> B[技术创新点是否突出?]
        A --> C[学习成长是否体现?]
        A --> D[解决方案是否独特?]
        A --> E[团队贡献是否明确?]
        
        B --> F[在显眼位置强调]
        C --> G[用对比数据展示]
        D --> H[详细阐述设计思路]
        E --> I[量化个人贡献度]
    ```
  </process>

  <criteria>
    ## 学术报告质量评价标准

    ### 内容质量（40%权重）
    - ✅ **技术深度充分**：展现对核心技术的深入理解
    - ✅ **问题解决完整**：从问题识别到方案实施的完整链条
    - ✅ **创新价值明确**：突出项目的技术创新和实用价值
    - ✅ **学习成长具体**：具体的技能提升和知识扩展

    ### 逻辑结构（25%权重）
    - ✅ **整体框架清晰**：章节安排合理，逻辑主线明确
    - ✅ **内容层次分明**：从概述到细节的渐进式展开
    - ✅ **前后呼应一致**：开头提出的问题在后文有明确回应
    - ✅ **论证链条完整**：每个结论都有充分的论证支撑

    ### 表达质量（20%权重）
    - ✅ **学术用词准确**：专业术语使用恰当，表达规范
    - ✅ **语句流畅清晰**：避免歧义，逻辑关系明确
    - ✅ **重点突出明确**：关键信息容易识别和理解
    - ✅ **图文并茂有效**：合理使用图表辅助说明

    ### 格式规范（15%权重）
    - ✅ **学术格式标准**：符合学术论文或技术报告规范
    - ✅ **排版美观整洁**：版式设计专业，视觉效果良好
    - ✅ **引用标注规范**：参考文献格式正确，引用完整
    - ✅ **代码展示清晰**：代码格式规范，注释充分

    ### 特色亮点（加分项）
    - 🌟 **技术深度超出预期**：展现高级的技术理解和应用
    - 🌟 **创新思路独特**：提出原创性的解决方案或优化思路
    - 🌟 **反思深度充分**：对项目经验的深层次思考和总结
    - 🌟 **实用价值明显**：项目成果具有明确的应用价值和推广意义
  </criteria>
</execution> 