<execution>
  <constraint>
    ## 学术展示的客观限制
    - **时间限制**：验收展示通常有严格的时间限制
    - **评审者背景**：评审者的技术背景和关注点可能不同
    - **展示环境**：可能的技术设备限制和网络条件
    - **紧张情绪**：展示者可能因紧张影响表现
    - **问题不可预测性**：无法完全预测所有可能的提问
  </constraint>

  <rule>
    ## 学术展示的强制规则
    - **逻辑清晰**：展示内容必须有清晰的逻辑结构和层次
    - **重点突出**：必须突出项目的核心技术和创新点
    - **证据支撑**：所有技术声明都必须有代码或数据支撑
    - **时间控制**：必须严格控制各部分的时间分配
    - **专业表达**：使用准确的技术术语和专业表达方式
  </rule>

  <guideline>
    ## 学术展示的指导原则
    - **观众导向**：根据评审者的背景调整展示深度和重点
    - **故事化叙述**：用故事化的方式串联技术点，增强吸引力
    - **互动性**：适当的互动可以增强展示效果
    - **自信从容**：通过充分准备建立自信，保持从容的展示状态
    - **灵活应变**：能够根据现场情况灵活调整展示策略
  </guideline>

  <process>
    ## 学术展示流程设计
    
    ### 展示结构框架 (总时长15-20分钟)
    
    ```mermaid
    gantt
        title 项目验收展示时间分配
        dateFormat X
        axisFormat %s
        
        section 开场介绍
        项目背景和目标 :done, intro, 0, 2
        技术栈概览 :done, tech, 2, 3
        
        section 核心展示
        架构设计展示 :active, arch, 3, 6
        核心功能演示 :demo, 6, 9
        代码亮点解析 :code, 9, 12
        
        section 深度分析
        技术创新点 :innovation, 12, 14
        工程实践亮点 :practice, 14, 16
        
        section 总结互动
        成果总结 :summary, 16, 17
        问答环节 :qa, 17, 20
    ```
    
    ### Phase 1: 开场引入 (3分钟)
    
    **开场策略**：
    ```mermaid
    flowchart LR
        A[项目背景] --> B[技术挑战]
        B --> C[解决方案概览]
        C --> D[技术栈选择]
        D --> E[展示路线图]
        
        style A fill:#e1f5fe
        style E fill:#f3e5f5
    ```
    
    **关键要素**：
    - **项目定位**：BattlefieldExplorationSystem的业务价值
    - **技术挑战**：项目面临的主要技术难题
    - **解决思路**：整体的技术解决方案
    - **技术选型**：Qt + C++17的选择理由
    
    ### Phase 2: 架构设计展示 (3分钟)
    
    ```mermaid
    graph TD
        A[整体架构] --> B[分层架构]
        A --> C[模块划分]
        A --> D[设计模式]
        
        B --> B1[表示层<br/>UI组件]
        B --> B2[业务层<br/>逻辑处理]
        B --> B3[数据层<br/>存储管理]
        
        C --> C1[核心模块]
        C --> C2[工具模块]
        C --> C3[配置模块]
        
        D --> D1[单例模式<br/>ConfigManager]
        D --> D2[观察者模式<br/>事件处理]
        D --> D3[工厂模式<br/>对象创建]
    ```
    
    **展示重点**：
    - **架构清晰性**：层次分明的架构设计
    - **模块化程度**：高内聚低耦合的模块划分
    - **设计模式应用**：合理的设计模式使用
    - **扩展性考虑**：未来扩展的架构支持
    
    ### Phase 3: 核心功能演示 (3分钟)
    
    **演示策略**：
    ```mermaid
    flowchart TD
        A[功能演示] --> B[核心业务流程]
        A --> C[用户交互体验]
        A --> D[性能表现]
        
        B --> B1[数据处理流程]
        B --> B2[算法执行过程]
        B --> B3[结果展示方式]
        
        C --> C1[界面响应性]
        C --> C2[操作便捷性]
        C --> C3[错误处理]
        
        D --> D1[启动速度]
        D --> D2[处理效率]
        D --> D3[内存使用]
    ```
    
    **演示要点**：
    - **功能完整性**：展示主要功能的完整实现
    - **用户体验**：流畅的用户交互和界面响应
    - **稳定性**：系统的稳定运行和错误处理
    - **性能表现**：良好的性能指标
    
    ### Phase 4: 代码亮点解析 (3分钟)
    
    ```mermaid
    mindmap
      root((代码亮点))
        技术深度
          现代C++特性
          Qt高级特性
          算法优化
        工程质量
          代码规范
          设计模式
          异常处理
        创新实现
          独特算法
          性能优化
          架构创新
        最佳实践
          内存管理
          并发处理
          配置管理
    ```
    
    **代码展示策略**：
    - **选择典型代码片段**：最能体现技术水平的代码
    - **解释设计思路**：为什么这样实现，有什么优势
    - **对比其他方案**：与常见实现方式的对比
    - **强调创新点**：独特的技术解决方案
    
    ### Phase 5: 技术创新总结 (2分钟)
    
    **创新点包装**：
    ```mermaid
    graph LR
        A[技术创新] --> A1[ConfigManager<br/>安全配置管理]
        A --> A2[现代C++<br/>特性应用]
        A --> A3[Qt框架<br/>深度使用]
        
        B[工程创新] --> B1[代码规范<br/>标准化]
        B --> B2[架构设计<br/>模块化]
        B --> B3[质量保证<br/>测试驱动]
        
        C[实践创新] --> C1[开发流程<br/>规范化]
        C --> C2[文档体系<br/>完整性]
        C --> C3[版本管理<br/>专业化]
        
        style A1 fill:#e8f5e9
        style B1 fill:#fff3e0
        style C1 fill:#f3e5f5
    ```
    
    ### Phase 6: 问答应对策略 (5-8分钟)
    
    **问题分类和应对**：
    
    | 问题类型 | 应对策略 | 示例回答框架 |
    |----------|----------|--------------|
    | 技术选型 | 对比分析 | "选择Qt是因为...相比其他框架的优势是..." |
    | 架构设计 | 原理解释 | "采用这种架构是为了...具体实现是..." |
    | 实现细节 | 代码展示 | "这个功能的核心实现是...让我展示关键代码..." |
    | 性能优化 | 数据说话 | "我们通过...优化，性能提升了...%" |
    | 扩展规划 | 前瞻思考 | "未来可以通过...方式扩展...功能" |
    
    **应答技巧**：
    - **PREP结构**：Point(观点) → Reason(理由) → Example(例子) → Point(重申)
    - **承认不足**：诚实承认不了解的部分，但展示学习能力
    - **引导话题**：将问题引导到自己熟悉的技术亮点
    - **保持自信**：即使遇到难题也要保持自信和从容
  </process>

  <criteria>
    ## 学术展示质量标准
    
    ### 内容质量标准
    - ✅ 技术内容准确无误，逻辑清晰
    - ✅ 重点突出，层次分明
    - ✅ 创新点明确，亮点突出
    - ✅ 深度适中，不过于复杂也不过于简单
    
    ### 展示技巧标准
    - ✅ 时间控制精准，节奏把握得当
    - ✅ 语言表达清晰，专业术语使用准确
    - ✅ 视觉辅助有效，图表清晰易懂
    - ✅ 互动自然，回答问题从容自信
    
    ### 专业形象标准
    - ✅ 展现出对项目的深度理解
    - ✅ 体现出扎实的技术功底
    - ✅ 表现出良好的工程素养
    - ✅ 显示出持续学习的能力
    
    ### 效果评估标准
    - ✅ 评审者对项目技术水平认可
    - ✅ 成功回答了大部分技术问题
    - ✅ 展示了项目的核心价值和创新点
    - ✅ 获得了理想的验收成绩
  </criteria>
</execution>
