<execution>
  <constraint>
    ## 海报设计客观限制
    - **尺寸规格约束**：A1(594×841mm)、A0(841×1189mm)等标准尺寸
    - **分辨率要求**：印刷级300DPI，展示级150DPI最低标准
    - **色彩模式限制**：印刷CMYK模式，数字展示RGB模式
    - **字体版权约束**：使用免费字体或获得授权的字体
    - **文件格式要求**：设计源文件(AI/PSD)和输出文件(PDF/JPG/PNG)
    - **制作时间限制**：高质量海报制作需要2-5个工作日
  </constraint>

  <rule>
    ## 强制性设计规则
    - **信息层次强制**：标题>副标题>核心内容>支撑信息>装饰元素
    - **可读性底线**：最小字体不低于12pt，重要信息不低于16pt
    - **对比度标准**：文字与背景对比度不低于4.5:1
    - **品牌一致性**：必须使用统一的品牌色彩和字体规范
    - **内容准确性**：所有技术信息和项目描述必须100%准确
    - **版权合规性**：所有使用的图片、图标、字体必须有合法授权
  </rule>

  <guideline>
    ## 设计指导原则
    - **目标导向**：设计必须服务于项目展示和传播目标
    - **受众适配**：根据观看距离和受众群体调整设计细节
    - **简洁有力**：信息精炼，视觉冲击力强，避免过度装饰
    - **专业性优先**：在美观与专业性冲突时，优先保证专业性
    - **可扩展性**：设计元素可用于其他宣传材料的延展
  </guideline>

  <process>
    ## 海报设计完整流程

    ### Phase 1: 需求分析与策划 (1-2小时)
    
    ```mermaid
    flowchart TD
        A[项目信息收集] --> B[目标受众分析]
        B --> C[展示场景确定]
        C --> D[核心信息提取]
        D --> E[设计策略制定]
        
        A1[项目技术特点<br/>团队组成<br/>核心亮点] --> A
        B1[学术评审<br/>同行交流<br/>公众展示] --> B
        C1[展板展示<br/>PPT插图<br/>网络传播] --> C
        D1[项目名称<br/>技术架构<br/>创新点<br/>应用价值] --> D
    ```
    
    **具体任务：**
    1. **项目调研**：深入了解战场探索系统的技术架构和特色
    2. **竞品分析**：研究同类项目海报的设计风格和信息组织
    3. **需求确认**：明确海报的使用场景、尺寸规格和交付要求
    4. **创意简报**：形成设计方向和核心创意概念

    ### Phase 2: 概念设计与布局 (2-3小时)
    
    ```mermaid
    graph TD
        A[设计概念确定] --> B[视觉风格定义]
        B --> C[信息架构设计]
        C --> D[布局草图绘制]
        D --> E[初步方案评估]
        
        style A fill:#e1f5fe
        style B fill:#f3e5f5
        style C fill:#fff3e0
        style D fill:#e8f5e9
        style E fill:#fce4ec
    ```
    
    **核心输出：**
    - **设计概念**：科技感军事风格，突出AI+多端协同特色
    - **色彩方案**：主色(深蓝/军绿) + 辅助色(橙色/银色) + 中性色(灰白)
    - **字体组合**：标题字体(科技感) + 正文字体(易读性) + 装饰字体(特效)
    - **布局框架**：主视觉区 + 信息展示区 + 技术架构区 + 品牌标识区

    ### Phase 3: 视觉元素制作 (4-6小时)
    
    ```mermaid
    flowchart LR
        A[图标设计] --> D[整体合成]
        B[插图绘制] --> D
        C[图表制作] --> D
        
        A --> A1[无人机图标<br/>机器狗图标<br/>AI大脑图标<br/>雷达扫描图标]
        B --> B1[系统架构图<br/>战场环境图<br/>协同工作图<br/>数据流向图]
        C --> C1[技术架构图<br/>功能模块图<br/>性能数据图<br/>对比分析图]
    ```
    
    **制作要点：**
    1. **图标系统**：统一风格的矢量图标，体现军事科技感
    2. **插图元素**：展现系统运行场景和技术特色的示意图
    3. **数据可视化**：将复杂技术信息转化为易懂的图表形式
    4. **装饰元素**：科技线条、光效、几何图形等氛围营造

    ### Phase 4: 内容编排与优化 (2-3小时)
    
    ```mermaid
    graph TD
        A[文字内容编排] --> B[视觉层次调整]
        B --> C[色彩搭配优化]
        C --> D[细节完善]
        D --> E[整体效果检验]
        
        E --> F{设计目标达成?}
        F -->|是| G[进入输出阶段]
        F -->|否| H[问题诊断]
        H --> I[针对性调整]
        I --> B
    ```
    
    **优化重点：**
    - **信息密度**：确保重要信息突出，次要信息不干扰主体
    - **视觉平衡**：左右、上下、色彩、明暗的视觉平衡
    - **阅读路径**：设计合理的视觉引导，形成清晰阅读流程
    - **一致性检查**：风格、色彩、字体、间距的统一性

    ### Phase 5: 输出交付与迭代 (1-2小时)
    
    ```mermaid
    flowchart TD
        A[多格式输出] --> B[质量检查]
        B --> C[用户验收]
        C --> D{需要修改?}
        D -->|是| E[意见收集]
        D -->|否| F[正式交付]
        E --> G[修改实施]
        G --> A
        
        A --> A1[设计源文件<br/>高清PDF<br/>JPG/PNG<br/>印刷文件]
    ```
    
    **交付标准：**
    - **设计源文件**：可编辑的AI/PSD格式，包含所有图层
    - **展示文件**：高分辨率PDF，适合各种展示场景
    - **网络版本**：优化的JPG/PNG，适合网络传播
    - **印刷版本**：CMYK色彩模式，符合印刷要求
  </process>

  <criteria>
    ## 设计质量评价标准

    ### 视觉效果评估
    - ✅ **视觉冲击力**：第一眼能否吸引注意力
    - ✅ **专业美观度**：整体设计是否专业、精致
    - ✅ **风格一致性**：各元素风格是否协调统一
    - ✅ **创新独特性**：是否有独特的创意亮点

    ### 信息传达效果
    - ✅ **信息清晰度**：关键信息是否清晰易读
    - ✅ **层次分明度**：信息重要性是否清晰区分
    - ✅ **理解便捷性**：观众是否能快速理解项目特色
    - ✅ **记忆持久性**：是否能在观众心中留下深刻印象

    ### 技术实现质量
    - ✅ **技术准确性**：技术描述是否准确无误
    - ✅ **制作精度**：设计制作是否精确细致
    - ✅ **文件规范性**：输出文件是否符合使用要求
    - ✅ **可用性保证**：各种使用场景是否都能良好展示

    ### 项目适配度
    - ✅ **目标匹配度**：是否符合项目展示目标
    - ✅ **受众适应性**：是否适合目标受众群体
    - ✅ **场景实用性**：是否适应实际使用场景
    - ✅ **品牌一致性**：是否符合项目整体形象定位
  </criteria>
</execution> 