<execution>
  <constraint>
    ## 视觉传达限制因素
    - **认知负载限制**：人类视觉处理能力有限，信息过载会导致理解困难
    - **观看时间约束**：海报浏览时间通常只有3-8秒，必须快速传达核心信息
    - **视觉习惯差异**：不同文化背景的受众视觉认知习惯存在差异
    - **技术理解门槛**：复杂技术概念需要适当简化才能被一般受众理解
    - **空间尺寸限制**：有限的海报空间需要精心规划信息密度
  </constraint>

  <rule>
    ## 视觉传达强制规则
    - **3秒法则**：核心信息必须在3秒内被观众识别和理解
    - **7±2信息法则**：单个视觉区域信息点不超过7个，避免认知过载
    - **对比优先级**：重要信息必须通过色彩、大小、位置对比突出显示
    - **一致性原则**：同类信息必须使用一致的视觉表现形式
    - **可访问性标准**：设计必须考虑视觉障碍人群的阅读需求
  </rule>

  <guideline>
    ## 视觉传达指导原则
    - **故事化表达**：用视觉叙事的方式组织信息，增强记忆效果
    - **隐喻化设计**：用熟悉的视觉隐喻帮助理解复杂概念
    - **情感化连接**：在理性信息基础上加入情感共鸣元素
    - **多层次设计**：为不同需求的观众提供不同深度的信息
    - **预期性设计**：设计符合观众预期的视觉表现形式
  </guideline>

  <process>
    ## 视觉传达策略实施流程

    ### Step 1: 信息分层与优先级设定
    
    ```mermaid
    graph TD
        A[项目信息收集] --> B[信息重要性评估]
        B --> C[受众需求分析]
        C --> D[信息分层规划]
        D --> E[视觉权重分配]
        
        B --> B1[核心价值信息<br/>技术创新信息<br/>应用场景信息<br/>团队背景信息]
        C --> C1[专业评审需求<br/>同行交流需求<br/>大众理解需求]
        D --> D1[第一层: 项目标识<br/>第二层: 核心特色<br/>第三层: 技术细节<br/>第四层: 支撑信息]
    ```
    
    **战场探索系统信息分层示例：**
    - **第一层（3秒内识别）**：项目名称、核心概念、视觉标识
    - **第二层（8秒内理解）**：AI+多端协同、技术架构、应用价值
    - **第三层（深度了解）**：具体技术实现、性能指标、创新亮点
    - **第四层（专业深入）**：开发工具、算法原理、团队分工

    ### Step 2: 视觉语言设计
    
    ```mermaid
    mindmap
      root((视觉语言))
        色彩语言
          主色调: 深蓝(专业稳重)
          强调色: 橙色(警示醒目)
          辅助色: 银色(科技未来)
          中性色: 灰白(信息背景)
        形态语言
          几何图形: 科技精确感
          有机曲线: 智能流动感
          直线构成: 军事严谨感
          网格系统: 结构化布局
        符号语言
          雷达圆圈: 探测扫描
          连接线条: 数据传输
          箭头指向: 功能流程
          发光效果: 智能激活
    ```

    ### Step 3: 叙事结构设计
    
    ```mermaid
    flowchart LR
        A[引入关注] --> B[展示价值] --> C[说明原理] --> D[证明效果] --> E[呼唤行动]
        
        A --> A1[震撼视觉<br/>项目标题]
        B --> B1[核心亮点<br/>创新特色]
        C --> C1[技术架构<br/>实现方式]
        D --> D1[应用场景<br/>实际效果]
        E --> E1[联系方式<br/>延伸了解]
    ```
    
    **战场探索系统叙事线：**
    1. **引入**：战场环境 + 探索需求 → 吸引关注
    2. **价值**：AI赋能 + 多端协同 → 展示创新
    3. **原理**：技术架构 + 系统集成 → 证明可行
    4. **效果**：实际应用 + 性能表现 → 建立信任
    5. **行动**：团队介绍 + 后续发展 → 促进交流

    ### Step 4: 视觉节奏控制
    
    ```mermaid
    graph TD
        A[视觉入口设计] --> B[信息流动规划]
        B --> C[视觉停留点设置]
        C --> D[阅读路径优化]
        D --> E[视觉出口引导]
        
        A --> A1[标题区强冲击<br/>主视觉吸眼球]
        B --> B1[左→右→下<br/>符合阅读习惯]
        C --> C1[关键信息节点<br/>适当停留缓冲]
        D --> D1[颜色、大小引导<br/>箭头、线条指向]
        E --> E1[联系信息区<br/>行动召唤区]
    ```

    ### Step 5: 情感共鸣设计
    
    ```mermaid
    mindmap
      root((情感层次))
        理性层面
          技术先进性
          应用实用性
          发展前景性
          团队专业性
        感性层面
          科技美感
          未来想象
          国防情怀
          创新精神
        价值层面
          社会贡献
          技术进步
          国防建设
          人才培养
    ```

    ### Step 6: 可用性测试与优化
    
    ```mermaid
    flowchart TD
        A[设计完成] --> B[多人群测试]
        B --> C[理解度评估]
        C --> D[问题识别]
        D --> E{需要调整?}
        E -->|是| F[针对性优化]
        E -->|否| G[最终确认]
        F --> B
        
        B --> B1[专业人士<br/>普通观众<br/>目标用户]
        C --> C1[3秒识别测试<br/>核心信息理解<br/>整体印象评价]
    ```
  </process>

  <criteria>
    ## 视觉传达效果评价标准

    ### 信息传达效率
    - ✅ **快速识别性**：3秒内能识别项目主题和核心价值
    - ✅ **层次清晰度**：不同重要级别的信息能被清晰区分
    - ✅ **理解准确性**：观众理解的信息与预期传达的信息一致
    - ✅ **记忆持久性**：关键信息能在观看后较长时间内被记住

    ### 视觉体验质量
    - ✅ **美感愉悦度**：整体视觉效果给人愉悦的美感体验
    - ✅ **专业可信度**：视觉表现传达出专业和可信的形象
    - ✅ **情感共鸣度**：能激发观众的情感共鸣和价值认同
    - ✅ **差异化特色**：有独特的视觉特色，与同类项目形成区分

    ### 功能实现效果
    - ✅ **目标达成度**：是否有效实现了预设的传达目标
    - ✅ **受众适配度**：是否适合目标受众的认知水平和审美偏好
    - ✅ **场景适用性**：是否适合预期的展示和使用场景
    - ✅ **扩展延续性**：视觉风格是否可以延续到其他宣传材料

    ### 技术执行质量
    - ✅ **视觉精度**：设计制作的精确度和细致程度
    - ✅ **色彩准确性**：色彩表现是否符合设计预期
    - ✅ **输出适配性**：不同输出格式和媒介的适配效果
    - ✅ **可维护性**：设计文件的组织结构和可编辑性
  </criteria>
</execution> 