#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
实时人体距离检测系统 - 核心模块包

包含以下模块:
- config: 配置文件
- person_detector: 人体检测模块
- distance_calculator: 距离计算模块
"""

__version__ = "1.0.0"
__author__ = "Distance Detection System"

# 导入核心模块
from .config import *
from .person_detector import PersonDetector
from .distance_calculator import DistanceCalculator
from .map_manager import MapManager
from .web_server import WebServer
from .mobile_connector import MobileConnector, MobileDevice
from .orientation_detector import OrientationDetector
from .web_orientation_detector import WebOrientationDetector

__all__ = [
    'PersonDetector',
    'DistanceCalculator',
    'MapManager',
    'WebServer',
    'MobileConnector',
    'MobileDevice',
    'CAMERA_INDEX',
    'FRAME_WIDTH',
    'FRAME_HEIGHT',
    'FPS',
    'MODEL_PATH',
    'CONFIDENCE_THRESHOLD',
    'IOU_THRESHOLD',
    'KNOWN_PERSON_HEIGHT',
    'FOCAL_LENGTH',
    'REFERENCE_DISTANCE',
    'REFERENCE_HEIGHT_PIXELS',
    'FONT',
    'FONT_SCALE',
    'FONT_THICKNESS',
    'BOX_COLOR',
    'TEXT_COLOR',
    'TEXT_BG_COLOR',
    'PERSON_CLASS_ID'
] 