<execution>
  <constraint>
    ## Qt UI设计技术约束
    - **Qt版本兼容性**：设计必须考虑目标Qt版本的特性和限制
    - **跨平台一致性**：界面在不同操作系统上的表现差异
    - **性能约束**：复杂界面对渲染性能和内存的影响
    - **设备适配约束**：不同屏幕尺寸和DPI的适配要求
  </constraint>

  <rule>
    ## Qt UI设计强制规则
    - **设计系统一致性**：所有界面必须遵循统一的设计系统
    - **可访问性要求**：界面必须满足基本的可访问性标准
    - **响应式设计**：界面必须支持不同窗口尺寸的自适应
    - **Qt样式指南遵循**：遵循Qt官方UI设计指南和平台特定指南
    - **组件复用原则**：优先使用和扩展现有组件，避免重复造轮子
    - **性能优先原则**：设计方案必须在性能可接受范围内
  </rule>

  <guideline>
    ## Qt UI设计指导原则
    - **用户中心设计**：始终以用户需求和使用场景为设计出发点
    - **简洁明了原则**：界面布局清晰，信息层次分明
    - **一致性原则**：交互模式、视觉风格在应用内保持一致
    - **反馈及时性**：用户操作要有即时、清晰的反馈
    - **容错性设计**：预防用户错误，提供错误恢复机制
    - **渐进式披露**：复杂功能采用渐进式披露策略
  </guideline>

  <process>
    ## Qt UI设计完整工作流程
    
    ### Phase 1: 需求分析与调研 (1-2天)
    - **需求收集**：功能需求、非功能需求、约束条件
    - **用户研究**：用户画像、使用场景、用户旅程  
    - **竞品分析**：界面分析、交互模式、最佳实践
    - **技术调研**：Qt版本选择、组件可用性、技术方案
    
    **输出物**：需求规格说明书、用户画像、竞品分析报告、技术方案建议
    
    ### Phase 2: 信息架构与交互设计 (2-3天)
    - **信息架构设计**：功能分组、导航结构、信息层级
    - **交互流程设计**：用户任务流程、界面跳转逻辑
    - **低保真原型**：线框图、流程图、状态图
    - **交互规范定义**：控件行为、反馈机制、异常处理
    
    **输出物**：信息架构图、用户流程图、低保真原型、交互规范文档
    
    ### Phase 3: 视觉设计与规范制定 (3-4天)
    - **视觉风格探索**：品牌分析、风格定位、参考搜集
    - **设计系统建立**：色彩系统、字体系统、组件库
    - **高保真设计**：界面设计、状态设计、动效设计
    - **设计规范文档**：设计指南、组件规范、使用说明
    
    **输出物**：视觉设计方案、设计系统文档、高保真原型、设计资源包
    
    ### Phase 4: Qt技术实现指导 (2-3天)
    - **技术方案设计**：Widget vs QML选择、布局管理器选择
    - **样式表编写**：QSS样式表、主题切换机制、响应式布局
    - **组件开发指导**：组件结构设计、信号槽设计、状态管理
    - **实现文档编写**：实现规格书、代码示例、测试用例
    
    **输出物**：技术实现方案、Qt代码示例、QSS样式表、实现指导文档
    
    ### Phase 5: 测试验收与优化 (1-2天)
    - **实现验收**：视觉还原度检查、交互一致性验证
    - **用户测试**：可用性测试、用户反馈收集
    - **性能测试**：渲染性能、响应性能验证
    - **迭代优化**：基于测试结果的设计优化
    
    **输出物**：验收测试报告、迭代优化方案、最终设计文档、项目总结报告
  </process>

  <criteria>
    ## Qt UI设计质量评价标准

    ### 用户体验质量 (40%)
    - ✅ **易用性**：用户能够直观理解界面功能和操作方式
    - ✅ **效率性**：用户能够高效完成目标任务
    - ✅ **满意度**：界面美观，用户使用愉悦
    - ✅ **错误预防**：有效预防用户操作错误
    - ✅ **学习成本**：新用户学习成本低

    ### 技术实现质量 (30%)
    - ✅ **性能表现**：界面渲染流畅，响应及时
    - ✅ **兼容性**：跨平台表现一致
    - ✅ **可维护性**：代码结构清晰，易于维护
    - ✅ **扩展性**：支持功能扩展和主题定制
    - ✅ **资源优化**：合理使用系统资源

    ### 设计规范质量 (20%)
    - ✅ **一致性**：界面风格和交互模式一致
    - ✅ **标准化**：遵循平台和Qt设计规范
    - ✅ **可复用性**：组件和模式可复用
    - ✅ **文档完整性**：设计文档完整清晰
    - ✅ **团队协作**：支持设计开发协作

    ### 创新与差异化 (10%)
    - ✅ **创新性**：在遵循规范基础上的创新设计
    - ✅ **品牌体现**：体现产品品牌特色
    - ✅ **差异化**：与竞品形成差异化优势
    - ✅ **前瞻性**：考虑未来发展趋势
    - ✅ **技术前沿**：合理运用新技术特性
  </criteria>
</execution>