<execution>
  <constraint>
    ## 界面优化技术约束
    - **Qt框架限制**：优化方案必须在Qt 5.15框架内可实现
    - **QSS能力边界**：样式优化受Qt样式表功能限制
    - **性能要求**：界面优化不能显著影响应用性能
    - **兼容性要求**：优化后界面需保持跨平台兼容性
    - **现有代码约束**：尽量避免大幅修改现有代码结构
  </constraint>

  <rule>
    ## 界面优化强制规则
    - **渐进式优化**：采用小步快跑的迭代优化策略，避免大规模重构
    - **用户体验优先**：所有优化必须以提升用户体验为根本目标
    - **代码质量保证**：优化过程中保持代码的可读性和可维护性
    - **测试验证强制**：每个优化改进都必须经过充分测试验证
    - **版本控制管理**：所有界面修改都要有清晰的版本记录和回滚能力
  </rule>

  <guideline>
    ## 界面优化指导原则
    - **问题导向**：从实际的用户体验问题出发进行优化
    - **数据支撑**：用可量化的指标评估优化效果
    - **用户反馈**：重视并及时响应用户对界面改进的反馈
    - **设计系统**：建立并维护一致的设计语言和规范
    - **持续改进**：将界面优化作为一个持续的迭代过程
  </guideline>

  <process>
    ## 🎯 界面优化完整工作流程
    
    ```mermaid
    flowchart TD
        A[现状调研] --> B[问题诊断]
        B --> C[优化方案设计]
        C --> D[技术可行性评估]
        D --> E[优化实施]
        E --> F[测试验证]
        F --> G[效果评估]
        G --> H{是否满意?}
        H -->|否| I[方案调整]
        H -->|是| J[上线部署]
        I --> C
        J --> K[持续监控]
        K --> L[下一轮优化]
        L --> A
    ```

    ### Phase 1: 现状调研 (深度分析阶段)
    
    ```mermaid
    mindmap
      root((现状调研))
        用户界面审查
          视觉设计评估
          交互流程分析
          信息架构检查
        用户体验测试
          可用性测试
          用户反馈收集
          痛点问题识别
        技术架构分析
          代码结构审查
          样式表分析
          性能瓶颈识别
        竞品对比分析
          行业标杆学习
          设计趋势把握
          差距识别分析
    ```
    
    **关键任务**：
    - 截图记录现有界面状态，建立baseline
    - 分析用户操作路径，识别体验痛点
    - 审查现有QSS样式表结构和组织方式
    - 收集用户对界面的直接反馈和建议
    
    **输出成果**：
    - 界面现状分析报告
    - 用户体验问题清单
    - 技术债务识别列表
    - 优化需求优先级排序

    ### Phase 2: 问题诊断 (系统化分析)
    
    ```mermaid
    graph TD
        A[问题收集] --> B{问题分类}
        B -->|视觉层面| C[配色/字体/图标问题]
        B -->|布局层面| D[间距/对齐/比例问题]
        B -->|交互层面| E[反馈/流程/效率问题]
        B -->|内容层面| F[信息/层次/可读性问题]
        
        C --> G[问题优先级评估]
        D --> G
        E --> G
        F --> G
        
        G --> H[解决方案匹配]
    ```
    
    **诊断维度**：
    - **严重程度**：影响核心功能 > 影响使用体验 > 影响视觉效果
    - **影响范围**：全局影响 > 模块影响 > 局部影响
    - **解决难度**：易于解决 > 中等难度 > 技术挑战
    - **用户关注度**：高频抱怨 > 偶尔提及 > 潜在问题

    ### Phase 3: 优化方案设计 (创意与技术结合)
    
    ```mermaid
    flowchart LR
        A[设计理念确定] --> B[视觉风格定义]
        B --> C[组件规范制定]
        C --> D[交互模式设计]
        D --> E[技术实现规划]
        E --> F[分阶段实施计划]
    ```
    
    **设计规范建立**：
    ```mermaid
    mindmap
      root((设计系统))
        色彩规范
          主色调定义
          辅助色搭配
          状态色标准
          渐变方案
        字体规范
          字体族选择
          字号层次
          字重搭配
          行间距标准
        间距规范
          基础间距单位
          组件内间距
          组件间间距
          页面边距
        组件规范
          按钮样式
          输入框样式
          卡片样式
          面板样式
    ```

    ### Phase 4: 技术可行性评估
    
    | 优化方案 | Qt支持度 | 实现难度 | 性能影响 | 兼容性 | 推荐度 |
    |---------|---------|---------|---------|--------|--------|
    | 色彩优化 | ✅ 完全支持 | 🟢 简单 | 🟢 无影响 | ✅ 良好 | ⭐⭐⭐⭐⭐ |
    | 圆角边框 | ✅ 完全支持 | 🟢 简单 | 🟢 无影响 | ✅ 良好 | ⭐⭐⭐⭐⭐ |
    | 渐变背景 | ✅ 完全支持 | 🟡 中等 | 🟡 轻微影响 | ✅ 良好 | ⭐⭐⭐⭐ |
    | 阴影效果 | 🟡 部分支持 | 🟡 中等 | 🟡 轻微影响 | 🟡 一般 | ⭐⭐⭐ |
    | 动画效果 | 🟡 部分支持 | 🔴 复杂 | 🔴 明显影响 | 🟡 一般 | ⭐⭐ |

    ### Phase 5: 优化实施 (分模块执行)
    
    ```mermaid
    gantt
        title 界面优化实施计划
        dateFormat  YYYY-MM-DD
        section 基础清理
        间距统一          :done, basic1, 2024-01-01, 2d
        对齐规范          :done, basic2, after basic1, 2d
        section 色彩优化
        色彩系统建立      :active, color1, 2024-01-05, 3d
        主题色调整        :color2, after color1, 2d
        section 组件美化
        按钮样式优化      :comp1, 2024-01-10, 2d
        面板样式优化      :comp2, after comp1, 3d
        section 细节完善
        图标更新          :detail1, 2024-01-15, 2d
        交互反馈优化      :detail2, after detail1, 2d
    ```
    
    **实施原则**：
    - 一次只优化一个模块，确保变更可控
    - 每个改动都要有备份和回滚方案
    - 及时测试，发现问题立即修正
    - 保持与项目团队的沟通协调

    ### Phase 6: 测试验证 (质量保证)
    
    ```mermaid
    flowchart TD
        A[功能测试] --> B[视觉测试]
        B --> C[用户体验测试]
        C --> D[性能测试]
        D --> E[兼容性测试]
        E --> F{所有测试通过?}
        F -->|否| G[问题修复]
        F -->|是| H[测试通过]
        G --> A
    ```
    
    **测试检查清单**：
    - ✅ 所有现有功能正常工作
    - ✅ 新的视觉效果正确显示
    - ✅ 界面响应速度没有下降
    - ✅ 不同分辨率下显示正常
    - ✅ 跨平台兼容性良好

    ### Phase 7: 效果评估 (成果量化)
    
    **评估指标体系**：
    ```mermaid
    mindmap
      root((优化效果))
        用户满意度
          界面美观度评分
          使用便利性评分
          整体满意度评分
        技术指标
          加载速度对比
          内存使用对比
          CPU使用对比
        业务指标
          用户使用时长
          功能使用频率
          错误操作减少率
    ```
    
    **数据收集方法**：
    - 用户满意度调研问卷
    - 界面操作时间对比测试
    - 系统性能监控数据分析
    - 用户行为数据统计分析
  </process>

  <criteria>
    ## 界面优化质量标准
    
    ### 视觉效果标准
    - ✅ 色彩搭配和谐，符合应用定位
    - ✅ 字体层次清晰，阅读舒适
    - ✅ 布局整齐美观，视觉平衡
    - ✅ 组件风格统一，品质专业
    
    ### 用户体验标准
    - ✅ 操作流程更加流畅直观
    - ✅ 重要功能更加突出易找
    - ✅ 界面反馈及时明确
    - ✅ 学习成本没有明显增加
    
    ### 技术实现标准
    - ✅ 代码结构清晰可维护
    - ✅ 性能表现不低于优化前
    - ✅ 跨平台兼容性良好
    - ✅ 样式表组织规范有序
    
    ### 项目管理标准
    - ✅ 按计划时间完成优化
    - ✅ 优化过程风险可控
    - ✅ 版本管理规范清晰
    - ✅ 文档记录完整准确
  </criteria>
</execution>